@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Iller::Configuration;
 
-our $VERSION = '0.1301'; # VERSION
+our $VERSION = '0.1302'; # VERSION
 
 use Dist::Iller::Elk;
 use namespace::autoclean;
@@ -223,7 +223,7 @@ sub to_string {
         my $previous_module = '';
 
         AUTHORDEP:
-        foreach my $authordep (sort { $a->module cmp $b->module } $self->filter_prereqs(sub { $_->relation eq 'requires' && $_->module ne 'perl' })) {
+        foreach my $authordep (sort { $a->module cmp $b->module } $self->filter_prereqs(sub { $_->relation eq 'requires' && $_->module ne 'perl' && $_->phase eq 'develop' })) {
             next AUTHORDEP if $authordep->module eq $previous_module;
             push @strings => sprintf '; authordep %s = %s', $authordep->module, $authordep->version;
             $has_author_deps = 1;
@@ -252,7 +252,7 @@ Dist::Iller::Configuration
 
 =head1 VERSION
 
-Version 0.1301, released 2016-02-03.
+Version 0.1302, released 2016-02-03.
 
 =head1 SOURCE
 
